import{S as v,i as w,s as g,d as m,v as _,a as l,b as t,c,e as k,f,n as d,g as $}from"./index.1327b829.js";const p="mnt/c/Users/islam/dev/gradio-repos/gradio/ui/packages/icons/src/File.svelte";function h(r){let e,s,n;const a={c:function(){e=l("svg"),s=l("path"),n=l("polyline"),t(s,"d","M13 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V9z"),c(s,p,11,2,228),t(n,"points","13 2 13 9 20 9"),c(n,p,13,3,302),t(e,"xmlns","http://www.w3.org/2000/svg"),t(e,"width","100%"),t(e,"height","100%"),t(e,"viewBox","0 0 24 24"),t(e,"fill","none"),t(e,"stroke","currentColor"),t(e,"stroke-width","1.5"),t(e,"stroke-linecap","round"),t(e,"stroke-linejoin","round"),t(e,"class","feather feather-file"),c(e,p,0,0,0)},l:function(i){throw new Error("options.hydrate only works if the component was compiled with the `hydratable: true` option")},m:function(i,u){k(i,e,u),f(e,s),f(e,n)},p:d,i:d,o:d,d:function(i){i&&$(e)}};return m("SvelteRegisterBlock",{block:a,id:h.name,type:"component",source:"",ctx:r}),a}function F(r,e){let{$$slots:s={},$$scope:n}=e;_("File",s,[]);const a=[];return Object.keys(e).forEach(o=>{!~a.indexOf(o)&&o.slice(0,2)!=="$$"&&o!=="slot"&&console.warn(`<File> was created with unknown prop '${o}'`)}),[]}class x extends v{constructor(e){super(e),w(this,e,F,h,g,{}),m("SvelteRegisterComponent",{component:this,tagName:"File",options:e,id:h.name})}}export{x as F};
