import{S as k,i as y,s as I,d,Z as $,v as S,Y as g,P as A,Q as F,J as w,h as E,k as J,b as R,c as j,e as B,f as O,m as L,g as P,w as Y,t as v,_ as N,$ as D,a0 as Q,D as h,E as b,B as Z,C as G,F as H}from"./index.1327b829.js";import{a as C}from"./CarouselItem.svelte_svelte_type_style_lang.54b4007c.js";const U="mnt/c/Users/islam/dev/gradio-repos/gradio/ui/packages/carousel/src/CarouselItem.svelte";function m(a){let e,r;const o={c:function(){e=E("div"),r=J(a[0]),R(e,"class","absolute left-0 top-0 py-1 px-2 rounded-br-lg shadow-sm text-xs text-gray-500 flex items-center pointer-events-none bg-white z-20 dark:bg-gray-800 s-fuQ2WouN3Ph9"),j(e,U,14,2,447)},m:function(s,t){B(s,e,t),O(e,r)},p:function(s,t){t&1&&L(r,s[0])},d:function(s){s&&P(e)}};return d("SvelteRegisterBlock",{block:o,id:m.name,type:"if",source:"(14:1) {#if label}",ctx:a}),o}function p(a){let e,r,o,n=a[0]&&m(a);const s=a[5].default,t=$(s,a,a[4],null),c={c:function(){e=E("div"),n&&n.c(),r=Y(),t&&t.c(),R(e,"class","carousel-item hidden component min-h-[200px] border rounded-lg overflow-hidden relative s-fuQ2WouN3Ph9"),v(e,"!block",a[1]===a[3]),j(e,U,9,0,296)},l:function(l){throw new Error("options.hydrate only works if the component was compiled with the `hydratable: true` option")},m:function(l,u){B(l,e,u),n&&n.m(e,null),O(e,r),t&&t.m(e,null),o=!0},p:function(l,[u]){l[0]?n?n.p(l,u):(n=m(l),n.c(),n.m(e,r)):n&&(n.d(1),n=null),t&&t.p&&(!o||u&16)&&N(t,s,l,l[4],o?Q(s,l[4],u,null):D(l[4]),null),u&10&&v(e,"!block",l[1]===l[3])},i:function(l){o||(h(t,l),o=!0)},o:function(l){b(t,l),o=!1},d:function(l){l&&P(e),n&&n.d(),t&&t.d(l)}};return d("SvelteRegisterBlock",{block:c,id:p.name,type:"component",source:"",ctx:a}),c}function K(a,e,r){let o,{$$slots:n={},$$scope:s}=e;S("CarouselItem",n,["default"]);let{label:t=void 0}=e;const{register:c,unregister:f,current:l}=g(C);A(l,"current"),F(a,l,i=>r(1,o=i));let u=c();w(()=>f(u));const z=["label"];return Object.keys(e).forEach(i=>{!~z.indexOf(i)&&i.slice(0,2)!=="$$"&&i!=="slot"&&console.warn(`<CarouselItem> was created with unknown prop '${i}'`)}),a.$$set=i=>{"label"in i&&r(0,t=i.label),"$$scope"in i&&r(4,s=i.$$scope)},a.$capture_state=()=>({onDestroy:w,getContext:g,CAROUSEL:C,label:t,register:c,unregister:f,current:l,id:u,$current:o}),a.$inject_state=i=>{"label"in i&&r(0,t=i.label),"id"in i&&r(3,u=i.id)},e&&"$$inject"in e&&a.$inject_state(e.$$inject),[t,o,l,u,s,n]}class W extends k{constructor(e){super(e),y(this,e,K,p,I,{label:0}),d("SvelteRegisterComponent",{component:this,tagName:"CarouselItem",options:e,id:p.name})}get label(){throw new Error("<CarouselItem>: Props cannot be read directly from the component instance unless compiling with 'accessors: true' or '<svelte:options accessors/>'")}set label(e){throw new Error("<CarouselItem>: Props cannot be set directly on the component instance unless compiling with 'accessors: true' or '<svelte:options accessors/>'")}}function q(a){let e;const r=a[0].default,o=$(r,a,a[1],null),n={c:function(){o&&o.c()},m:function(t,c){o&&o.m(t,c),e=!0},p:function(t,c){o&&o.p&&(!e||c&2)&&N(o,r,t,t[1],e?Q(r,t[1],c,null):D(t[1]),null)},i:function(t){e||(h(o,t),e=!0)},o:function(t){b(o,t),e=!1},d:function(t){o&&o.d(t)}};return d("SvelteRegisterBlock",{block:n,id:q.name,type:"slot",source:"(4:0) <CarouselItem>",ctx:a}),n}function _(a){let e,r;e=new W({props:{$$slots:{default:[q]},$$scope:{ctx:a}},$$inline:!0});const o={c:function(){Z(e.$$.fragment)},l:function(s){throw new Error("options.hydrate only works if the component was compiled with the `hydratable: true` option")},m:function(s,t){G(e,s,t),r=!0},p:function(s,[t]){const c={};t&2&&(c.$$scope={dirty:t,ctx:s}),e.$set(c)},i:function(s){r||(h(e.$$.fragment,s),r=!0)},o:function(s){b(e.$$.fragment,s),r=!1},d:function(s){H(e,s)}};return d("SvelteRegisterBlock",{block:o,id:_.name,type:"component",source:"",ctx:a}),o}function M(a,e,r){let{$$slots:o={},$$scope:n}=e;S("CarouselItem",o,["default"]);const s=[];return Object.keys(e).forEach(t=>{!~s.indexOf(t)&&t.slice(0,2)!=="$$"&&t!=="slot"&&console.warn(`<CarouselItem> was created with unknown prop '${t}'`)}),a.$$set=t=>{"$$scope"in t&&r(1,n=t.$$scope)},a.$capture_state=()=>({CarouselItem:W}),[o,n]}class T extends k{constructor(e){super(e),y(this,e,M,_,I,{}),d("SvelteRegisterComponent",{component:this,tagName:"CarouselItem_1",options:e,id:_.name})}}var x=T;const ee=["static"];export{x as Component,ee as modes};
